==> DAAG_0.34.tar.gz: DAAG/data/socsupport.R <==
"socsupport" <-
structure(list(gender = structure(c(2, 1, 2, 2, 1, 1, 1, 1, 1, 
2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
2, 1, 2, 1, 2, 2, 2, 1, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 1, 2, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 1, 2, 1, 1, 1, 2, 
1, 1), .Label = c("female", "male"), class = c("AsIs", "factor"
)), age = structure(c(2, 2, 2, 1, 2, 2, 3, 3, 1, 5, 2, 1, 2, 
1, 2, 2, 3, 5, 1, 2, 1, 1, 4, 5, 3, 1, 1, 5, 1, 1, 1, 1, 2, 1, 
1, 1, 1, 2, 4, 2, 1, 1, 1, 4, 4, 2, 2, 2, 2, 3, 1, 1, 1, 1, 1, 
1, 1, 2, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 2, 4, 2, 3, 2, 4, 2, 2, 2, 2, 1, 1, 2, 1, 2, 2), .Label = c("18-20", 
"21-24", "25-30", "31-40", "40+"), class = c("AsIs", "factor"
)), country = structure(c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 2, 1, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2), .Label = c("australia", 
"other"), class = c("AsIs", "factor")), marital = structure(c(2, 
3, 3, 3, 3, 3, 1, 1, 3, 2, 3, 3, 3, 3, 3, 3, 2, 2, 3, 3, 3, 3, 
1, 1, 2, 3, 3, 1, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 
1, 2, 3, 3, 3, 2, 2, 3, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 3, 3, 1, 
3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 2, 
2, 3, 3, 3, 3, 3, 3, 3, 3, 3), .Label = c("married", "other", 
"single"), class = c("AsIs", "factor")), livewith = structure(c(5, 
5, 6, 4, 2, 2, 5, 5, 4, 1, 4, 6, 3, 6, 4, 4, 5, 5, 4, 4, 6, 6, 
5, 5, 4, 2, 4, 5, 2, 6, 4, 6, 4, 4, 4, 6, 4, 6, 1, 4, 4, 6, 4, 
5, 5, 4, 4, 4, 5, 5, 6, 4, 6, 4, 6, 4, 2, 5, 4, 4, 4, 4, 6, 5, 
4, 4, 4, 4, 4, 4, 4, 4, 6, 4, 4, 4, 6, 6, 6, 3, 5, 5, 4, 4, 3, 
5, 6, 6, 2, 4, 6, 2, 5, 5, 5), .Label = c("alone", "friends", 
"other", "parents", "partner", "residences"), class = c("AsIs", 
"factor")), employment = structure(c(2, 5, 2, 2, 2, 3, 2, 2, 
2, 2, 2, 2, 2, 3, 3, 2, 1, 4, 4, 5, 5, 5, 4, 1, 2, 2, 2, 4, 2, 
3, 2, 3, 2, 5, 4, 3, 2, 5, 4, 2, 2, 2, 5, 4, 4, 4, 2, 2, 2, 2, 
4, 2, 3, 5, 5, 4, 3, 3, 2, 4, 4, 5, 5, 2, 2, 2, 2, 3, 5, 2, 2, 
5, 3, 2, 2, 2, 5, 5, 4, 2, 2, 4, 3, 5, 2, 3, 2, 5, 5, 5, 2, 2, 
3, 2, 2), .Label = c("employed fulltime", "employed part-time", 
"govt assistance", "other", "parental support"), class = "factor"), 
    firstyr = structure(c(2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 2, 2, 
    2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    2, 2, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 2, 
    2, 2, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    2, 1, 1, 2, 2, 2, 2), .Label = c("first year", "other"), class = c("AsIs", 
    "factor")), enrolment = structure(c(2, 2, 2, 2, 2, 2, 2, 
    3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 3, 2, 2, 
    2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 3, 2, 
    3, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 
    3, 2, 3, 2, 1, 2, 2, 2, 2, 2, 2, 3, 2, 3, 1, 2, 2, 2, 2, 
    1, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2), .Label = c("", "full-time", 
    "part-time"), class = c("AsIs", "factor")), emotional = c(22, 
    21, 21, 19, 16, 20, 20, 20, 24, 13, 20, 19, 25, 21, 20, 22, 
    20, 20, 16, 20, 17, 21, 25, 22, 25, 22, 20, 21, 21, 11, 15, 
    14, 20, 23, 21, 6, 19, 17, 25, 20, 21, 19, 23, 17, 19, 18, 
    25, 20, 20, 21, 17, 19, 20, 23, 12, 20, 17, 25, 16, 19, 24, 
    10, 15, 19, 20, 12, 13, 21, 16, 19, 24, 20, 13, 18, 16, 25, 
    20, 16, 21, 18, 18, 25, 16, 24, 18, 21, 20, 22, 14, 23, 21, 
    19, 13, 17, 22), emotionalsat = c(23, 20, 18, 19, 19, 17, 
    23, 20, 25, 18, 18, 19, 25, 19, 20, 22, 20, 20, 19, 20, 20, 
    18, 25, 22, 25, 20, 23, 23, 22, 15, 13, 16, 19, 22, 20, 8, 
    20, 17, 25, 19, 20, 19, 19, 19, 21, 24, 25, 20, 20, 20, 19, 
    19, 20, 24, 13, 20, 19, 25, 17, 19, 23, 16, 18, 19, 21, 12, 
    NA, 22, 17, 20, 25, 20, 13, 17, 20, 24, 20, 19, 21, 19, 16, 
    25, 20, 24, 15, 25, 20, 23, 16, 21, 22, 20, 18, 18, 22), 
    tangible = c(17, 12, 16, 20, 11, 16, 20, 16, 20, 6, 13, 14, 
    20, 13, 14, 20, 15, 9, 20, 20, 14, 11, 16, 20, 20, 17, 16, 
    14, 20, 7, 19, 13, 20, 20, 20, 4, 20, 12, 17, 15, 17, 14, 
    20, 16, 18, 17, 20, 20, 12, 14, 4, 20, 20, 20, NA, 20, 19, 
    20, 19, 19, 19, 19, 16, 20, 19, 19, 15, 8, 20, 18, 15, 18, 
    15, 20, 14, 20, 17, 10, 11, 20, 18, 18, 8, 18, 20, 17, 20, 
    18, 18, 18, 20, 11, 13, 17, 20), tangiblesat = c(18, 10, 
    16, 17, 15, 15, 20, 16, 20, 14, 13, 16, 20, 11, 15, 20, 16, 
    12, 20, 20, 14, 12, 17, 20, 20, 20, 18, 17, 19, 8, 19, 13, 
    19, 20, 19, 8, 20, 14, 20, 18, 15, 14, 19, 16, 18, 20, 20, 
    20, 13, 16, NA, 16, 20, 20, NA, 20, 19, 20, 18, 18, 18, 19, 
    16, 20, 20, 16, NA, 12, 20, 19, 19, 17, 15, 18, 15, 20, 17, 
    13, 13, 16, 18, 20, 16, 19, 16, 17, 20, 18, 18, 17, 20, 12, 
    16, 17, 17), affect = c(15, 10, 15, 11, 6, 12, 14, 12, 15, 
    6, 13, 14, 15, 9, 15, 14, 13, 12, 10, 12, 10, 9, 15, 14, 
    15, 13, 13, 15, 12, 7, 11, 4, 10, 15, 15, 3, 14, 8, 12, 15, 
    15, 8, 15, 12, 14, 10, 15, 15, 13, 14, 10, 13, 13, 14, 9, 
    15, 14, 15, 10, 12, 15, 6, 9, 14, 14, 7, 8, 6, 15, 11, 15, 
    14, 10, 11, 8, 6, 11, 10, 10, 12, 10, 15, 10, 15, 10, 15, 
    13, 15, 10, 14, 15, 12, 15, 15, 14), affectsat = c(15, 6, 
    15, 11, 10, 14, 15, 12, 15, 12, 14, 12, 15, 7, 15, 14, 13, 
    12, 11, 14, 12, 9, 15, 14, 15, 13, 13, 15, 12, 7, 9, 7, 7, 
    15, 15, 3, 14, 14, 13, 14, 15, 9, 13, 12, 15, 13, 15, 15, 
    15, 13, 15, 12, 13, 15, 9, 15, 14, 15, 10, 12, 15, 5, 11, 
    14, 14, 5, 8, 10, 15, 9, 15, 13, 13, 11, 10, 6, 12, 11, 11, 
    12, 9, 15, 12, 15, 10, 15, 13, 15, 10, 14, 15, 12, 15, 14, 
    14), psi = c(12, 9, 13, 13, 11, 12, 15, 12, 12, 6, 11, 10, 
    15, 9, 13, 12, 12, 12, 9, 13, 13, 12, 15, 12, 15, 13, 12, 
    14, 13, 8, 11, 8, 12, 15, 14, 5, 15, 11, 10, 14, 11, 12, 
    11, 12, 12, 15, 15, 15, 10, 11, 10, 12, 15, 11, 9, 10, 12, 
    15, 7, 12, 14, 6, 11, 15, 13, 8, 12, 11, 10, 15, 14, 14, 
    8, 11, 7, 15, 14, 10, 12, 11, 6, 13, 10, 14, 10, 11, 15, 
    12, 11, 12, 15, 11, 12, 14, 12), psisat = c(13, 6, 12, 12, 
    12, 11, 15, 12, 15, 11, 12, 8, 15, 8, 13, 14, 12, 12, 10, 
    14, 12, 12, 15, 12, 15, 14, 12, 15, 13, 10, 10, 14, 12, 15, 
    15, 6, 15, 14, 12, 12, 12, 12, 11, 12, 12, 15, 15, 15, 12, 
    12, 12, 12, 15, 11, 8, 12, 12, 15, 8, 12, 14, 5, 11, 15, 
    13, 6, 13, 13, 11, 15, 15, 13, 8, 12, 10, 15, 13, 12, 12, 
    11, 6, 13, 12, 15, 10, 13, 14, 13, 11, 12, 15, 11, 12, 14, 
    11), esupport = c(13, 12, 14, 15, 9, 13, 15, 13, 16, 10, 
    12, 8, 16, 14, 11, 17, 14, 14, NA, 13, 13, 15, 14, 12, 15, 
    13, 14, 13, 16, 8, 14, 13, 13, 15, 17, 6, 16, 10, 10, 13, 
    15, 14, 14, 9, 9, 11, 16, 14, 11, 17, 8, 12, 19, 12, 11, 
    15, 11, 14, 12, 13, 16, 9, 9, 16, 15, 12, 13, 12, 8, 14, 
    14, 13, 10, 11, 8, 16, 18, 10, 12, 13, 9, 14, 12, 11, 10, 
    13, 16, 10, 10, 13, 15, 14, 12, 14, 12), psupport = c(11, 
    7, 13, 15, 7, 12, 10, 11, NA, 8, 8, 6, 10, 10, 10, 14, 9, 
    5, NA, 11, 11, 9, 12, 10, 16, 11, 15, 7, 15, 9, 10, 6, 12, 
    13, 15, 4, 15, 15, 10, 9, 10, 8, 14, 6, 5, 10, 13, 20, 7, 
    10, 4, 8, 17, 8, 5, 8, 13, 14, 8, 12, 14, 8, 8, 12, 12, 10, 
    13, 10, 13, 14, 12, 10, 8, 10, 11, 16, 11, 5, 10, 12, 4, 
    14, 5, 8, 6, 10, 17, 8, 11, 9, 13, 9, 7, 9, 11), socsupport = c(13, 
    10, 14, 15, 9, 13, 13, 11, NA, 9, 14, 5, 12, 10, 8, 14, 12, 
    10, NA, 11, 11, 11, 14, 10, 14, 10, 11, 7, 14, 9, 9, 8, 12, 
    14, 13, 5, 15, 15, 9, 11, 10, 10, 11, 7, 8, 10, 13, 16, 10, 
    12, 6, 10, 14, 12, 8, 11, 13, 12, 7, 12, 14, 11, 8, 14, 10, 
    8, 11, 11, 10, 11, 14, 9, 8, 9, 7, 14, 9, 8, 11, 12, 8, 13, 
    11, 10, 9, 10, 16, 9, 11, 9, 11, 11, 10, 11, 10), BDI = c(5, 
    8, 16, 0, 9, 0, 1, 14, 12, 20, 13, 34, 8, 15, 0, 6, 6, 0, 
    8, 0, 11, 21, 9, 0, 6, 3, 16, 1, 20, 9, 9, 21, 2, 2, 7, 46, 
    9, 11, 15, 8, 7, 11, 7, 1, 2, 0, 7, 10, 0, 5, 0, 17, 6, 19, 
    11, 9, 22, 13, 32, 13, 11, 16, 7, 7, 10, 23, 14, 48, 12, 
    5, 6, 21, 28, 14, 7, 4, 8, 4, 12, 2, 28, 2, 3, 6, 12, 11, 
    3, 2, 7, 21, 8, 11, 10, 8, 38)), .Names = c("gender", "age", 
"country", "marital", "livewith", "employment", "firstyr", "enrolment", 
"emotional", "emotionalsat", "tangible", "tangiblesat", "affect", 
"affectsat", "psi", "psisat", "esupport", "psupport", "socsupport", 
"BDI"), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", 
"9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
"20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", 
"31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", 
"42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", 
"53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", 
"64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", 
"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", 
"86", "87", "88", "89", "90", "91", "92", "93", "94", "95"), class = "data.frame")

==> DAAG_1.00.tar.gz: DAAG/data/socsupport.R <==
"socsupport" <-
structure(list(gender = structure(c(2, 1, 2, 2, 1, 1, 1, 1, 1, 
2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
2, 1, 2, 1, 2, 2, 2, 1, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 1, 2, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 1, 2, 1, 1, 1, 2, 
1, 1), .Label = c("female", "male"), class = c("AsIs", "factor"
)), age = structure(c(2, 2, 2, 1, 2, 2, 3, 3, 1, 5, 2, 1, 2, 
1, 2, 2, 3, 5, 1, 2, 1, 1, 4, 5, 3, 1, 1, 5, 1, 1, 1, 1, 2, 1, 
1, 1, 1, 2, 4, 2, 1, 1, 1, 4, 4, 2, 2, 2, 2, 3, 1, 1, 1, 1, 1, 
1, 1, 2, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 2, 4, 2, 3, 2, 4, 2, 2, 2, 2, 1, 1, 2, 1, 2, 2), .Label = c("18-20", 
"21-24", "25-30", "31-40", "40+"), class = c("AsIs", "factor"
)), country = structure(c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 2, 1, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2), .Label = c("australia", 
"other"), class = c("AsIs", "factor")), marital = structure(c(2, 
3, 3, 3, 3, 3, 1, 1, 3, 2, 3, 3, 3, 3, 3, 3, 2, 2, 3, 3, 3, 3, 
1, 1, 2, 3, 3, 1, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 
1, 2, 3, 3, 3, 2, 2, 3, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 3, 3, 1, 
3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 2, 
2, 3, 3, 3, 3, 3, 3, 3, 3, 3), .Label = c("married", "other", 
"single"), class = c("AsIs", "factor")), livewith = structure(c(5, 
5, 6, 4, 2, 2, 5, 5, 4, 1, 4, 6, 3, 6, 4, 4, 5, 5, 4, 4, 6, 6, 
5, 5, 4, 2, 4, 5, 2, 6, 4, 6, 4, 4, 4, 6, 4, 6, 1, 4, 4, 6, 4, 
5, 5, 4, 4, 4, 5, 5, 6, 4, 6, 4, 6, 4, 2, 5, 4, 4, 4, 4, 6, 5, 
4, 4, 4, 4, 4, 4, 4, 4, 6, 4, 4, 4, 6, 6, 6, 3, 5, 5, 4, 4, 3, 
5, 6, 6, 2, 4, 6, 2, 5, 5, 5), .Label = c("alone", "friends", 
"other", "parents", "partner", "residences"), class = c("AsIs", 
"factor")), employment = structure(c(2, 5, 2, 2, 2, 3, 2, 2, 
2, 2, 2, 2, 2, 3, 3, 2, 1, 4, 4, 5, 5, 5, 4, 1, 2, 2, 2, 4, 2, 
3, 2, 3, 2, 5, 4, 3, 2, 5, 4, 2, 2, 2, 5, 4, 4, 4, 2, 2, 2, 2, 
4, 2, 3, 5, 5, 4, 3, 3, 2, 4, 4, 5, 5, 2, 2, 2, 2, 3, 5, 2, 2, 
5, 3, 2, 2, 2, 5, 5, 4, 2, 2, 4, 3, 5, 2, 3, 2, 5, 5, 5, 2, 2, 
3, 2, 2), .Label = c("employed fulltime", "employed part-time", 
"govt assistance", "other", "parental support"), class = "factor"), 
    firstyr = structure(c(2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 2, 2, 
    2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    2, 2, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 2, 
    2, 2, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    2, 1, 1, 2, 2, 2, 2), .Label = c("first year", "other"), class = c("AsIs", 
    "factor")), enrolment = structure(c(2, 2, 2, 2, 2, 2, 2, 
    3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 3, 2, 2, 
    2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 3, 2, 
    3, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 
    3, 2, 3, 2, 1, 2, 2, 2, 2, 2, 2, 3, 2, 3, 1, 2, 2, 2, 2, 
    1, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2), .Label = c("", "full-time", 
    "part-time"), class = c("AsIs", "factor")), emotional = c(22, 
    21, 21, 19, 16, 20, 20, 20, 24, 13, 20, 19, 25, 21, 20, 22, 
    20, 20, 16, 20, 17, 21, 25, 22, 25, 22, 20, 21, 21, 11, 15, 
    14, 20, 23, 21, 6, 19, 17, 25, 20, 21, 19, 23, 17, 19, 18, 
    25, 20, 20, 21, 17, 19, 20, 23, 12, 20, 17, 25, 16, 19, 24, 
    10, 15, 19, 20, 12, 13, 21, 16, 19, 24, 20, 13, 18, 16, 25, 
    20, 16, 21, 18, 18, 25, 16, 24, 18, 21, 20, 22, 14, 23, 21, 
    19, 13, 17, 22), emotionalsat = c(23, 20, 18, 19, 19, 17, 
    23, 20, 25, 18, 18, 19, 25, 19, 20, 22, 20, 20, 19, 20, 20, 
    18, 25, 22, 25, 20, 23, 23, 22, 15, 13, 16, 19, 22, 20, 8, 
    20, 17, 25, 19, 20, 19, 19, 19, 21, 24, 25, 20, 20, 20, 19, 
    19, 20, 24, 13, 20, 19, 25, 17, 19, 23, 16, 18, 19, 21, 12, 
    NA, 22, 17, 20, 25, 20, 13, 17, 20, 24, 20, 19, 21, 19, 16, 
    25, 20, 24, 15, 25, 20, 23, 16, 21, 22, 20, 18, 18, 22), 
    tangible = c(17, 12, 16, 20, 11, 16, 20, 16, 20, 6, 13, 14, 
    20, 13, 14, 20, 15, 9, 20, 20, 14, 11, 16, 20, 20, 17, 16, 
    14, 20, 7, 19, 13, 20, 20, 20, 4, 20, 12, 17, 15, 17, 14, 
    20, 16, 18, 17, 20, 20, 12, 14, 4, 20, 20, 20, NA, 20, 19, 
    20, 19, 19, 19, 19, 16, 20, 19, 19, 15, 8, 20, 18, 15, 18, 
    15, 20, 14, 20, 17, 10, 11, 20, 18, 18, 8, 18, 20, 17, 20, 
    18, 18, 18, 20, 11, 13, 17, 20), tangiblesat = c(18, 10, 
    16, 17, 15, 15, 20, 16, 20, 14, 13, 16, 20, 11, 15, 20, 16, 
    12, 20, 20, 14, 12, 17, 20, 20, 20, 18, 17, 19, 8, 19, 13, 
    19, 20, 19, 8, 20, 14, 20, 18, 15, 14, 19, 16, 18, 20, 20, 
    20, 13, 16, NA, 16, 20, 20, NA, 20, 19, 20, 18, 18, 18, 19, 
    16, 20, 20, 16, NA, 12, 20, 19, 19, 17, 15, 18, 15, 20, 17, 
    13, 13, 16, 18, 20, 16, 19, 16, 17, 20, 18, 18, 17, 20, 12, 
    16, 17, 17), affect = c(15, 10, 15, 11, 6, 12, 14, 12, 15, 
    6, 13, 14, 15, 9, 15, 14, 13, 12, 10, 12, 10, 9, 15, 14, 
    15, 13, 13, 15, 12, 7, 11, 4, 10, 15, 15, 3, 14, 8, 12, 15, 
    15, 8, 15, 12, 14, 10, 15, 15, 13, 14, 10, 13, 13, 14, 9, 
    15, 14, 15, 10, 12, 15, 6, 9, 14, 14, 7, 8, 6, 15, 11, 15, 
    14, 10, 11, 8, 6, 11, 10, 10, 12, 10, 15, 10, 15, 10, 15, 
    13, 15, 10, 14, 15, 12, 15, 15, 14), affectsat = c(15, 6, 
    15, 11, 10, 14, 15, 12, 15, 12, 14, 12, 15, 7, 15, 14, 13, 
    12, 11, 14, 12, 9, 15, 14, 15, 13, 13, 15, 12, 7, 9, 7, 7, 
    15, 15, 3, 14, 14, 13, 14, 15, 9, 13, 12, 15, 13, 15, 15, 
    15, 13, 15, 12, 13, 15, 9, 15, 14, 15, 10, 12, 15, 5, 11, 
    14, 14, 5, 8, 10, 15, 9, 15, 13, 13, 11, 10, 6, 12, 11, 11, 
    12, 9, 15, 12, 15, 10, 15, 13, 15, 10, 14, 15, 12, 15, 14, 
    14), psi = c(12, 9, 13, 13, 11, 12, 15, 12, 12, 6, 11, 10, 
    15, 9, 13, 12, 12, 12, 9, 13, 13, 12, 15, 12, 15, 13, 12, 
    14, 13, 8, 11, 8, 12, 15, 14, 5, 15, 11, 10, 14, 11, 12, 
    11, 12, 12, 15, 15, 15, 10, 11, 10, 12, 15, 11, 9, 10, 12, 
    15, 7, 12, 14, 6, 11, 15, 13, 8, 12, 11, 10, 15, 14, 14, 
    8, 11, 7, 15, 14, 10, 12, 11, 6, 13, 10, 14, 10, 11, 15, 
    12, 11, 12, 15, 11, 12, 14, 12), psisat = c(13, 6, 12, 12, 
    12, 11, 15, 12, 15, 11, 12, 8, 15, 8, 13, 14, 12, 12, 10, 
    14, 12, 12, 15, 12, 15, 14, 12, 15, 13, 10, 10, 14, 12, 15, 
    15, 6, 15, 14, 12, 12, 12, 12, 11, 12, 12, 15, 15, 15, 12, 
    12, 12, 12, 15, 11, 8, 12, 12, 15, 8, 12, 14, 5, 11, 15, 
    13, 6, 13, 13, 11, 15, 15, 13, 8, 12, 10, 15, 13, 12, 12, 
    11, 6, 13, 12, 15, 10, 13, 14, 13, 11, 12, 15, 11, 12, 14, 
    11), esupport = c(13, 12, 14, 15, 9, 13, 15, 13, 16, 10, 
    12, 8, 16, 14, 11, 17, 14, 14, NA, 13, 13, 15, 14, 12, 15, 
    13, 14, 13, 16, 8, 14, 13, 13, 15, 17, 6, 16, 10, 10, 13, 
    15, 14, 14, 9, 9, 11, 16, 14, 11, 17, 8, 12, 19, 12, 11, 
    15, 11, 14, 12, 13, 16, 9, 9, 16, 15, 12, 13, 12, 8, 14, 
    14, 13, 10, 11, 8, 16, 18, 10, 12, 13, 9, 14, 12, 11, 10, 
    13, 16, 10, 10, 13, 15, 14, 12, 14, 12), psupport = c(11, 
    7, 13, 15, 7, 12, 10, 11, NA, 8, 8, 6, 10, 10, 10, 14, 9, 
    5, NA, 11, 11, 9, 12, 10, 16, 11, 15, 7, 15, 9, 10, 6, 12, 
    13, 15, 4, 15, 15, 10, 9, 10, 8, 14, 6, 5, 10, 13, 20, 7, 
    10, 4, 8, 17, 8, 5, 8, 13, 14, 8, 12, 14, 8, 8, 12, 12, 10, 
    13, 10, 13, 14, 12, 10, 8, 10, 11, 16, 11, 5, 10, 12, 4, 
    14, 5, 8, 6, 10, 17, 8, 11, 9, 13, 9, 7, 9, 11), supsources = c(13, 
    10, 14, 15, 9, 13, 13, 11, NA, 9, 14, 5, 12, 10, 8, 14, 12, 
    10, NA, 11, 11, 11, 14, 10, 14, 10, 11, 7, 14, 9, 9, 8, 12, 
    14, 13, 5, 15, 15, 9, 11, 10, 10, 11, 7, 8, 10, 13, 16, 10, 
    12, 6, 10, 14, 12, 8, 11, 13, 12, 7, 12, 14, 11, 8, 14, 10, 
    8, 11, 11, 10, 11, 14, 9, 8, 9, 7, 14, 9, 8, 11, 12, 8, 13, 
    11, 10, 9, 10, 16, 9, 11, 9, 11, 11, 10, 11, 10), BDI = c(5, 
    8, 16, 0, 9, 0, 1, 14, 12, 20, 13, 34, 8, 15, 0, 6, 6, 0, 
    8, 0, 11, 21, 9, 0, 6, 3, 16, 1, 20, 9, 9, 21, 2, 2, 7, 46, 
    9, 11, 15, 8, 7, 11, 7, 1, 2, 0, 7, 10, 0, 5, 0, 17, 6, 19, 
    11, 9, 22, 13, 32, 13, 11, 16, 7, 7, 10, 23, 14, 48, 12, 
    5, 6, 21, 28, 14, 7, 4, 8, 4, 12, 2, 28, 2, 3, 6, 12, 11, 
    3, 2, 7, 21, 8, 11, 10, 8, 38)), .Names = c("gender", "age", 
"country", "marital", "livewith", "employment", "firstyr", "enrolment", 
"emotional", "emotionalsat", "tangible", "tangiblesat", "affect", 
"affectsat", "psi", "psisat", "esupport", "psupport", "supsources", 
"BDI"), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", 
"9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
"20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", 
"31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", 
"42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", 
"53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", 
"64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", 
"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", 
"86", "87", "88", "89", "90", "91", "92", "93", "94", "95"), class = "data.frame")
